==> java-enum-transform-1.0.4.tgz: package/es/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/**
 * Java enum transform
 * @author 余聪
 */
import * as globby from 'globby';
import * as fsExtra from 'fs-extra';
import { pascalCase } from 'change-case';
import { parse } from 'java-parser';
import { formatItemToTs, formatToTs, parseEnumCode } from './parse-enum-code';
import { parseFileMeta } from './parse-file';
import { resolveExpressionValue } from './resolve-values';
export function javaEnumTransformByDir(dir, { ignore = [], pattern = '**/*.java', deRef = true } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const filenames = yield globby(pattern, {
            absolute: true,
            onlyFiles: true,
            ignore,
            cwd: dir
        });
        const tmpFileMap = new Map();
        const fileMap = new Map();
        yield Promise.all(filenames.map((filename) => __awaiter(this, void 0, void 0, function* () {
            const code = yield fsExtra.readFile(filename, 'utf-8');
            const ast = parse(code);
            const meta = parseFileMeta(ast, { filename, classPath: dir });
            const id = meta.package ? meta.package.concat(meta.name).join('.') : null;
            if (id) {
                tmpFileMap.set(id, {
                    id,
                    meta,
                    ast
                });
            }
        })));
        const sortedKeys = Array.from(tmpFileMap.keys()).sort();
        sortedKeys.forEach((name) => {
            fileMap.set(name, tmpFileMap.get(name));
            tmpFileMap.delete(name);
        });
        const deRefOptions = {
            _visitMap: new Map(),
            getAstMapByPackage: (prefix) => {
                const map = {};
                const ids = [...fileMap.keys()];
                ids.forEach((id) => {
                    const namespace = prefix + '.';
                    if (id.startsWith(namespace)) {
                        const name = id.slice(namespace.length);
                        if (!name.includes('.') && fileMap.get(id)) {
                            map[name] = fileMap.get(id).ast;
                        }
                    }
                });
                return map;
            },
            getAstById: (id) => {
                var _a;
                return (_a = fileMap.get(id)) === null || _a === void 0 ? void 0 : _a.ast;
            },
            map: new Map()
        };
        function deRefFn(list, file) {
            const resolveExpressionValueInner = (item, fieldName) => {
                if (!item) {
                    return;
                }
                try {
                    return resolveExpressionValue(item, Object.assign(Object.assign({}, deRefOptions), { id: file.id, fieldName }));
                }
                catch (e) {
                    e.message = `解析 Enum 数据出错, id: ${file.id}, enum: ${fieldName}
  ${e.message}`;
                    throw e;
                }
            };
            list.forEach((item) => {
                item.enums.forEach((enumItem) => {
                    if (enumItem.label) {
                        enumItem.label = resolveExpressionValueInner(enumItem.label, enumItem.name);
                    }
                    if (enumItem.value) {
                        enumItem.value = resolveExpressionValueInner(enumItem.value, enumItem.name);
                    }
                });
            });
        }
        const result = new Map();
        yield Promise.all(Array.from(fileMap.entries())
            .filter(([, file]) => file.meta.type === 'enum')
            .map(([pkgName, file]) => __awaiter(this, void 0, void 0, function* () {
            const list = parseEnumCode(file.ast);
            if (deRef) {
                deRefFn(list, file);
            }
            result.set(pkgName, list);
        })));
        return result;
    });
}
export function resultToCode(map) {
    let mergedList = [];
    for (const [, list] of map.entries()) {
        mergedList = mergedList.concat(list);
    }
    const cache = new Map();
    return formatToTs(mergedList, {
        transformEnumName: (name) => {
            if (!/enum$/i.test(name)) {
                name = pascalCase(name + ' enum');
            }
            if (!cache.has(name)) {
                cache.set(name, 0);
                return name;
            }
            cache.set(name, cache.get(name) + 1);
            return `${name}${cache.get(name)}`;
        }
    });
}
/**
 * 单个文件独立渲染
 * @param item
 * @returns
 */
export function resultItemToCode(item) {
    return formatItemToTs(item, {
        transformEnumName: (name) => {
            if (!/enum$/i.test(name)) {
                name = pascalCase(name + ' enum');
            }
            return name;
        }
    });
}

==> java-enum-transform-1.0.6.tgz: package/es/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/**
 * Java enum transform
 * @author 余聪
 */
import * as globby from 'globby';
import * as fsExtra from 'fs-extra';
import { pascalCase } from 'change-case';
import { parse } from 'java-parser';
import { formatToTs, parseEnumCode } from './parse-enum-code';
import { parseFileMeta } from './parse-file';
import { resolveExpressionValue } from './resolve-values';
export function javaEnumTransformByDir(dir, { ignore = [], pattern = '**/*.java', deRef = true } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const filenames = yield globby(pattern, {
            absolute: true,
            onlyFiles: true,
            ignore,
            cwd: dir
        });
        const tmpFileMap = new Map();
        const fileMap = new Map();
        yield Promise.all(filenames.map((filename) => __awaiter(this, void 0, void 0, function* () {
            const code = yield fsExtra.readFile(filename, 'utf-8');
            const ast = parse(code);
            const meta = parseFileMeta(ast, { filename, classPath: dir });
            const id = meta.package ? meta.package.concat(meta.name).join('.') : null;
            if (id) {
                tmpFileMap.set(id, {
                    id,
                    meta,
                    ast
                });
            }
        })));
        const sortedKeys = Array.from(tmpFileMap.keys()).sort();
        sortedKeys.forEach((name) => {
            fileMap.set(name, tmpFileMap.get(name));
            tmpFileMap.delete(name);
        });
        const deRefOptions = {
            _visitMap: new Map(),
            getAstMapByPackage: (prefix) => {
                const map = {};
                const ids = [...fileMap.keys()];
                ids.forEach((id) => {
                    const namespace = prefix + '.';
                    if (id.startsWith(namespace)) {
                        const name = id.slice(namespace.length);
                        if (!name.includes('.') && fileMap.get(id)) {
                            map[name] = fileMap.get(id).ast;
                        }
                    }
                });
                return map;
            },
            getAstById: (id) => {
                var _a;
                return (_a = fileMap.get(id)) === null || _a === void 0 ? void 0 : _a.ast;
            },
            map: new Map()
        };
        function deRefFn(list, file) {
            const resolveExpressionValueInner = (item, fieldName) => {
                if (!item) {
                    return;
                }
                try {
                    return resolveExpressionValue(item, Object.assign(Object.assign({}, deRefOptions), { id: file.id, fieldName }));
                }
                catch (e) {
                    e.message = `解析 Enum 数据出错, id: ${file.id}, enum: ${fieldName}
  ${e.message}`;
                    throw e;
                }
            };
            list.forEach((item) => {
                item.enums.forEach((enumItem) => {
                    if (enumItem.label) {
                        enumItem.label = resolveExpressionValueInner(enumItem.label, enumItem.name);
                    }
                    if (enumItem.value) {
                        enumItem.value = resolveExpressionValueInner(enumItem.value, enumItem.name);
                    }
                });
            });
        }
        const result = new Map();
        yield Promise.all(Array.from(fileMap.entries())
            .filter(([, file]) => file.meta.type === 'enum')
            .map(([pkgName, file]) => __awaiter(this, void 0, void 0, function* () {
            const list = parseEnumCode(file.ast);
            if (deRef) {
                deRefFn(list, file);
            }
            result.set(pkgName, list);
        })));
        return result;
    });
}
export function resultToCode(map) {
    let mergedList = [];
    for (const [, list] of map.entries()) {
        mergedList = mergedList.concat(list);
    }
    const cache = new Map();
    return formatToTs(mergedList, {
        transformEnumName: (name) => {
            if (!/enum$/i.test(name)) {
                name = pascalCase(name + ' enum');
            }
            if (!cache.has(name)) {
                cache.set(name, 0);
                return name;
            }
            cache.set(name, cache.get(name) + 1);
            return `${name}${cache.get(name)}`;
        }
    });
}
/**
 * 单个文件独立渲染
 * @param item
 * @returns
 */
export function resultItemToCode(item) {
    return formatToTs(item, {
        transformEnumName: (name) => {
            if (!/enum$/i.test(name)) {
                name = pascalCase(name + ' enum');
            }
            return name;
        }
    });
}
